# Flutter Ghost Content API

A flutter wrapper around the [Ghost Content API](https://docs.ghost.org/api/content/).

## Blog post Explanation

See this [Ghost Content API blog post](https://learnsoftware.app/flutter-ghost-content-api-plugin/) for a more in-depth explanation of the package.

## Usage

Before anything else, you will need to create a custom integration in your blog admin portal and make note of the Content API Key and URL.

Next, create a `GhostContentAPIProvider` at the root of your Flutter application:

```
class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return GhostContentAPIProvider(
      client: GhostContentAPIClient(
        version: 'v2',
        url: 'https://your-subdomain.ghost.io',
        contentAPIkey: 'your content api key',
      ),
      child: MaterialApp(
        title: 'Flutter Demo',       
        home: MyHomePage(),
      ),
    );
  }
}
```

Finally, you can use a `FutureBuilder` anywhere you would like to access your Ghost content:

```
class MyHomePage extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Flutter Ghost"),
      ),
      body: FutureBuilder(
        future: GhostContentAPIProvider.of(context).getPosts(),
        builder: (BuildContext context, AsyncSnapshot<PostsResponse> snapshot) {
          // Build your UI
        },
      ),
    );
  }
}
```

Alternatively, all calls through the Ghost Content API client returns a simple `Future`, so you can use any mechanism you need to for your app. 

## Example

See the [Flutter Ghost App](https://gitlab.com/learn-software/learn-software-app) for [Learn Software](https://learnsoftware.app) for real-world usage.

## Tests

You can test this package by running the following commands: 

- `flutter packages get`
- `flutter test`

## Issues and Contributing

See the [GitLab project](https://gitlab.com/learnsoftwareapp/flutter_ghost_content_api). 
